"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = __importDefault(require("axios"));
function createBaseClient() {
    var baseHeaders = { "Content-Type": "application/json" };
    function createConfig(config) {
        return __assign({}, baseHeaders, (!!config ? config.headers : {}));
    }
    return {
        get: function (url, config) {
            return axios_1.default.get(url, createConfig(config)).then(function (_a) {
                var data = _a.data;
                return data;
            });
        },
        post: function (url, body, config) {
            return axios_1.default.post(url, body, createConfig(config)).then(function (_a) {
                var data = _a.data;
                return data;
            });
        },
        patch: function (url, body, config) {
            return axios_1.default.patch(url, body, createConfig(config)).then(function (_a) {
                var data = _a.data;
                return data;
            });
        }
    };
}
exports.createBaseClient = createBaseClient;
/**
 * Treat client and server as if originating from the same domain, and whatever
 * URL the client is at, the server has the corresponding URL that contains the
 * data.
 *
 * e.g.
 * client -> https://localhost:8000/users/
 * server -> https://localhost:8000/users/1
 */
function createRelativeClient(window, client) {
    function getFullURL(url) {
        return "" + window.location.origin + url;
    }
    return {
        get: function (url, config) { return client.get(getFullURL(url), config); },
        post: function (url, body, config) { return client.post(getFullURL(url), body, config); },
        patch: function (url, body, config) { return client.patch(getFullURL(url), body, config); }
    };
}
exports.createRelativeClient = createRelativeClient;
